@@ -2,19 +2,18 @@ package Lingua::Han::PinYin;
 
 use strict;
 use vars qw($VERSION);
-$VERSION = '0.03';
+$VERSION = '0.04';
 
-use Encode;
 use File::Spec;
+use Lingua::Han::Utils qw/Unihan_value/;
 
 sub new {
 	my $class = shift;
 	my $dir = __FILE__; $dir =~ s/\.pm//o;
 	-d $dir or die "Directory $dir nonexistent!";
-	my $self = { '_dir_' => $dir, @_ };
-	unless ($self->{'format'}) { $self->{'format'} = 'gb2312'; }
+	my $self = { @_ };
 	my %py;
-	my $file = File::Spec->catfile($self->{'_dir_'}, 'Mandarin.dat');
+	my $file = File::Spec->catfile($dir, 'Mandarin.dat');
 	open(FH, $file)	or die "$file: $!";
 	while(<FH>) {
 		my ($uni, $py) = split(/\s+/);
@@ -28,8 +27,7 @@ sub new {
 sub han2pinyin {
 	my ($self, $hanzi) = @_;
 	
-	$hanzi = decode ( $self->{'format'} , $hanzi); # decode it
-	my @code = map { uc sprintf("%x",$_) } unpack ("U*",$hanzi);
+	my @code = Unihan_value($hanzi);
 
 	my @result;
 	foreach my $code (@code) {
@@ -58,17 +56,12 @@ Lingua::Han::PinYin - Retrieve the Mandarin(PinYin) of Chinese character(HanZi).
 
   use Lingua::Han::PinYin;
   
-  # if the format of your script is gb2312, default
   my $h2p = new Lingua::Han::PinYin();
   print $h2p->han2pinyin("我"); # wo
-  
-  # if the format of your script is utf-8
-  my $h2p = new Lingua::Han::PinYin(format => 'utf8');
-  print $h2p->han2pinyin("我"); # wo
   my @result = $h2p->han2pinyin("爱你"); # @result = ('ai', 'ni');
   
   # we can set the tone up
-  my $h2p = new Lingua::Han::PinYin(format => 'utf8', tone => 1);
+  my $h2p = new Lingua::Han::PinYin(tone => 1);
   print $h2p->han2pinyin("我"); #wo3
   my @result = $h2p->han2pinyin("爱你"); # @result = ('ai4', 'ni3');
   print $h2p->han2pinyin("林道"); #lin2dao4
@@ -92,10 +85,6 @@ if not(I mean it's not a Chinese character), returns the original word;
 
 =over 4
 
-=item format => 'utf8|gb2312'
-
-If you are in 'Unicode Editing' mode, plz set this to utf8, otherwise('ASCII Editing') use the default.
-
 =item tone => 1|0
 
 default is 0. if tone is needed, plz set this to 1.
